@@ -11,7 +11,7 @@ public class Surface implements VideoConstants
 	// instance variables
 	protected gnu.gcj.RawData implementation = null;
 	protected PixelFormat format = null;
-	protected byte[] pixels = null;
+	protected byte[] pixelArray = null;
 
 	// class methods
 	public static native String getVideoDriverName();
@@ -57,15 +57,28 @@ public class Surface implements VideoConstants
 		return result;
 	}
 
-	public static native Surface createRGBSurface(int flags, 
+	public static Surface createRGBSurface(int flags, 
 		int width, int height, int bpp,
-		int rmask, int gmask, int bmask, int amask);
+		int rmask, int gmask, int bmask, int amask)
+	{
+		return new Surface(flags, width, height, bpp,
+			rmask, gmask, bmask, amask);
+	}
 
 	// constructors
-	protected Surface() 
+	public Surface() 
 	{ 
 	}
 
+	public Surface(int flags, 
+		int width, int height, int bpp,
+		int rmask, int gmask, int bmask, int amask)
+	{ 
+		this.initWithRGBSurface(flags, 
+			width, height, bpp,
+			rmask, gmask, bmask, amask);
+	}
+
 	// instance methods
 	public native int getFlags();
 	public native int getW();
@@ -132,6 +145,10 @@ public class Surface implements VideoConstants
 
 	public native void displayForamtAlpha();
 
+	public native void convertSurface(PixelFormat format, int flags);
+
+	public native Surface cloneSurface();
+
 	public native PixelFormat getPixelFormat();
 
 	public native void setPalette(Color[] palette);
@@ -181,5 +198,9 @@ public class Surface implements VideoConstants
 		this.freeSurface();
 		super.finalize();
 	}
+
+	private native void initWithRGBSurface(int flags, 
+		int width, int height, int bpp,
+		int rmask, int gmask, int bmask, int amask);
 }
 
